Error types for Morphir models
This module provides error handling following functional programming principles with clear error types and composable error handling.
Enums
- Error
- Main error type for Morphir model operations
Type Aliases
- Result
- Result type alias for Morphir operations