pub struct EntryPoint {
pub target: String,
pub kind: EntryPointKind,
pub doc: Option<String>,
}Expand description
Entry point definition
Keyed by a name the author chooses, holding the value it names, the kind of entry it is, and
an optional doc, which is written only when it is present.
Fields
target: StringThe entry point’s target, a canonical FQName string.
kind: EntryPointKinddoc: Option<String>Trait Implementations
Sourceimpl Clone for EntryPoint
impl Clone for EntryPoint
Sourceimpl Debug for EntryPoint
impl Debug for EntryPoint
Sourceimpl<'de> Deserialize<'de> for EntryPoint
impl<'de> Deserialize<'de> for EntryPoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for EntryPoint
impl PartialEq for EntryPoint
Sourceimpl Serialize for EntryPoint
impl Serialize for EntryPoint
impl StructuralPartialEq for EntryPoint