pub struct PredicateDeclaration { /* private fields */ }Expand description
One verified predicate supplied by an external declaration closure.
Implementations
Sourceimpl PredicateDeclaration
impl PredicateDeclaration
pub fn value( uri: NodeUri, object: ObjectDeclaration, subjects: impl IntoIterator<Item = SubjectRole>, interpretation: Interpretation, ) -> Self
Sourcepub fn sidecar_type(
uri: NodeUri,
object: ObjectDeclaration,
subjects: impl IntoIterator<Item = SubjectRole>,
) -> Self
pub fn sidecar_type( uri: NodeUri, object: ObjectDeclaration, subjects: impl IntoIterator<Item = SubjectRole>, ) -> Self
One legacy decorator type specification admitted only through its sidecar.
Sourcepub fn json_datatype(&self) -> Option<&NodeUri>
pub fn json_datatype(&self) -> Option<&NodeUri>
The declared datatype needed by @json context expansion.