Module module_name
morphir_
core
0.2.0
Module module_
name
Module Items
Structs
In morphir_
core::
naming
morphir_core
::
naming
Module
module_
name
Structs

Module
Name
ModuleName is a newtype wrapper around Path for type safety. It distinguishes module paths from package paths at the type level.